@@ -4,6 +4,7 @@ from disnake import HTTPException, Message, MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
 from disnake.ext.commands import Context
 
+
 class ChangeView(View):
     def __init__(self, ctx: Context):
         super().__init__()
@@ -19,69 +20,71 @@ class ChangeView(View):
             interaction.author == self.ctx.author
             and interaction.channel == self.ctx.channel
         )
-        
+
     def check(self, m: Message):
-        return (
-            m.author == self.ctx.author
-            and m.channel == self.ctx.channel
-        )
+        return m.author == self.ctx.author and m.channel == self.ctx.channel
 
     @button(label="Name", style=ButtonStyle.green)
-    async def name_button(
-        self, button: Button, interaction: MessageInteraction
-    ): 
+    async def name_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, 
-            "Change", 
-            path="change/name",
-            description="Changing my name"
+            self.ctx, "Change", path="change/name", description="Changing my name"
         )
-        await self.bot_message.edit(embed=embed)  
+        await self.bot_message.edit(embed=embed)
         await interaction.response.send_message("What username?", ephemeral=True)
 
         message: Message
-        while len(((message:= await self.bot.wait_for("message", check=self.check))).content) not in range(2, 33):
-            await interaction.message.reply("My username must be between `2-32` characters in length")
+        while len(
+            ((message := await self.bot.wait_for("message", check=self.check))).content
+        ) not in range(2, 33):
+            await interaction.message.reply(
+                "My username must be between `2-32` characters in length"
+            )
 
         try:
             await self.bot.user.edit(username=message.content)
         except HTTPException:
-            await interaction.message.reply("Something went wrong - Maybe you have been changing my name too often")
+            await interaction.message.reply(
+                "Something went wrong - Maybe you have been changing my name too often"
+            )
 
         embed = EmbedFactory.static_embed(
-            self.ctx, 
-            "Change", 
+            self.ctx,
+            "Change",
             path="change/name/success",
-            description=f"I changed my name to {message.content}"
+            description=f"I changed my name to {message.content}",
         )
         await self.bot_message.edit(embed=embed)
 
     @button(label="Avatar", style=ButtonStyle.green)
-    async def avatar_button(
-        self, button: Button, interaction: MessageInteraction
-    ):  
+    async def avatar_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, 
-            "Change", 
+            self.ctx,
+            "Change",
             path="change/avatar",
-            description="Changing my avatar - Send an image"
+            description="Changing my avatar - Send an image",
+        )
+        await self.bot_message.edit(embed=embed)
+        await interaction.response.send_message(
+            "What avatar? send an image", ephemeral=True
         )
-        await self.bot_message.edit(embed=embed)  
-        await interaction.response.send_message("What avatar? send an image", ephemeral=True)
 
         message: Message
-        while not ((message:= await self.bot.wait_for("message", check=self.check))).attachments:
+        while not (
+            (message := await self.bot.wait_for("message", check=self.check))
+        ).attachments:
             await interaction.message.reply("You must send an image file!")
 
         try:
             await self.bot.user.edit(avatar=await message.attachments[0].read())
         except HTTPException:
-            await interaction.message.reply("Something went wrong - Maybe you have been changing my avatar too often")
+            await interaction.message.reply(
+                "Something went wrong - Maybe you have been changing my avatar too often"
+            )
 
         embed = EmbedFactory.static_embed(
-            self.ctx, 
-            "Change", 
+            self.ctx,
+            "Change",
             path="change/avatar/success",
-            description=f"I changed my avatar successfully!"
+            description=f"I changed my avatar successfully!",
         )
-        await self.bot_message.edit(embed=embed)
\ No newline at end of file
+        await self.bot_message.edit(embed=embed)
